@@ -6,7 +6,8 @@ function(datos)
   library('relimp')
   Ma<-datos$datos
   longitud<-Ma[dim(Ma)[1],1]-Ma[1,1]
-  Require("caMassClass")
+  Require("PROcess")
+  #Require("caMassClass")
   paso<-Met.modalDialog("Binning","Size of the'bin'       ","0.04",entryWidth=8)
   breaks<-round(longitud/paso)
   Try(binning(Ma, breaks = breaks))
